@@ -1,9 +1,6 @@
-use strict;
-
 package CPAN::Test::Dummy::Perl5::Make::Zip;
-use vars qw{$VERSION};
 
-$VERSION = '1.02';
+$VERSION = '1.01';
 
 1;
 
